<?php

namespace SM\Service;

use SM\Factory\Sm00024000ModeloDocumentoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DataSource\DataSet;
use SM\Service\FileServerService;
use SM\Util\Utilities;
use Zeedhi\Framework\DependencyInjection\InstanceManager;

class Sm00024000ModeloDocumentoService
{

    protected $ModeloDocumentoFactory;
    protected $Environment;
    protected $newCode;
    protected $fileServerService;
    protected $fileServerUrl;

    public function __construct(EntityManager $entityManager, Sm00024000ModeloDocumentoFactory $ModeloDocumentoFactory, Environment $Environment, NewCode $newCode, FileServerService $fileServerService, $fileServerUrl)
    {
        $this->ModeloDocumentoFactory = $ModeloDocumentoFactory;
        $this->connection             = $entityManager->getConnection();
        $this->Environment            = $Environment;
        $this->newCode                = $newCode;
        $this->fileServerService      = $fileServerService;
        $this->fileServerUrl          = $fileServerUrl;
    }
 
    public function getInformacoesModeloDocumento()
    {
        return $this->ModeloDocumentoFactory->getInformacoesModeloDocumento();
    }

    public function getTabAnexo($params)
    {
        $paramsaux = array(
            "NRSEQMODDOCFCT"   => $params['NRSEQMODDOCFCT']
        );
        return $this->ModeloDocumentoFactory->getTabAnexo($paramsaux);
    }

    public function inserirModeloDocumento($parametros)
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        $nrseqmoddocfct = $this->newCode->getCodeByTableName("FCT_MODELODOC", $nrorg, 1, 10, true);
            $params = array(
                "NRSEQMODDOCFCT" => $nrseqmoddocfct,
                "DSMODELODOCORCA" => $parametros['DSMODELODOCORCA'],
                "IDATIVO" => $parametros['IDATIVO'],
                "IDDOCRENEGOCIACAO" => $parametros['IDDOCRENEGOCIACAO'],
                "VRTAMANHOLOGO" => $parametros['VRTAMANHOLOGO'],
                "NRORG"          => $nrorg,
                "NRORGINCLUSAO"  => $nrorg,
                "CDOPERINCLUSAO" => $cdoperador,
            );
            $this->ModeloDocumentoFactory->inserirModeloDocumento($params);
    }

    public function inserirModeloDocumentoIdioma($parametros)
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        $this->connection->beginTransaction();
        
        $paramsauxdoc = array(
            "NRSEQMODDOCFCT" => $parametros['NRSEQMODDOCFCT'],
        );

        $nmarquivo = $this->ModeloDocumentoFactory->getDocumentoAnt($paramsauxdoc);

        $paramsauxdocidioma = array(
            "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
            "CDIDIOM"           => $parametros['CDIDIOM'],
            "NRMODELODOCIDIOMA" => $parametros['NRMODELODOCIDIOMA'],
        );

        $valor = $this->ModeloDocumentoFactory->validaDocIdioma($paramsauxdocidioma);

        if ($valor[0]["QTD"] > 0 || ($parametros["IDPADRAO"] == "S" && $nmarquivo[0]["NMARQUIVO"] != null && $parametros["IDPADRAO_OLD"] != "S")) {
            throw new \Exception("EXISTE");
        }
        
        try {
            if (count($parametros['ARQUIVO']) > 0) {
                $dados = $this->fileServerService->uploadFiles($parametros['ARQUIVO'], 'anexo_modelo_documento');
                $dados[0]["size"] = $dados[0]["size"]/1024;
            } else {
                $dados = [[
                    "path" => $parametros["DSCAMINHOARQ"],
                    "size" => $parametros["VRTAMANHO"],
                    "name" => $parametros["NMARQUIVO"],
                    "type" => $parametros["DSTIPO"],
                ]];
            }

            if ($parametros["IDPADRAO"] == "S") {
                $params = array(
                    "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                    "NMARQUIVO"         => $dados[0]["name"],
                    "DSCAMINHOARQ"      => $dados[0]["path"],
                    "DSTIPO"            => $dados[0]["type"],
                    "VRTAMANHO"         => $dados[0]["size"],
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $cdoperador
                );

                $this->ModeloDocumentoFactory->atualizarModeloDocumento($params);
            }

            if ($parametros['NRMODELODOCIDIOMA'] == null) {
                $nrmodelodocidioma = $this->newCode->getCodeByTableName("FCT_MODELODOCIDIOMA", $nrorg, 1, 10, true);
                $params = array(
                    "NRMODELODOCIDIOMA" => $nrmodelodocidioma,
                    "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                    "CDIDIOM"           => $parametros['CDIDIOM'],
                    "IDATIVO"           => $parametros['IDATIVO'],
                    "NMARQUIVO"         => $dados[0]['name'],
                    "DSCAMINHOARQ"      => $dados[0]['path'],
                    "DSTIPO"            => $dados[0]['type'],
                    "VRTAMANHO"         => $dados[0]['size'],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $cdoperador,
                );
                
                $this->ModeloDocumentoFactory->inserirModeloDocumentoIdioma($params);

                if ($parametros["IDPADRAO"] == "N" && $parametros["IDPADRAO_OLD"] == "S") {
                    $params = array(
                        "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                    );
                    
                    $this->ModeloDocumentoFactory->limparAnexoTabModeloDoc($params);
                }
            } else {
                $params = array(
                    "NRMODELODOCIDIOMA" => $parametros['NRMODELODOCIDIOMA'],
                    "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                    "CDIDIOM"           => $parametros['CDIDIOM'],
                    "IDATIVO"           => $parametros['IDATIVO'],
                    "NMARQUIVO"         => $dados[0]["name"],
                    "DSCAMINHOARQ"      => $dados[0]["path"],
                    "DSTIPO"            => $dados[0]["type"],
                    "VRTAMANHO"         => $dados[0]["size"],
                    "NRORGULTATU"       => $nrorg,
                    "CDOPERULTATU"      => $cdoperador
                );
                
                $this->ModeloDocumentoFactory->atualizarModeloDocumentoIdioma($params);

                if ($parametros["IDPADRAO"] == "N" && $parametros["IDPADRAO_OLD"] == "S") {
                    $params = array(
                        "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                    );
                    
                    $this->ModeloDocumentoFactory->limparAnexoTabModeloDoc($params);
                }
            }
            
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function saveTabModeloDocumento($parametros)
    {
        $nrorg = $this->Environment->getNrorg();
        $cdoperador = $this->Environment->getCdOperador();
        $this->connection->beginTransaction();
        try {
            $params = array(
                "NRSEQMODDOCFCT"    => $parametros['NRSEQMODDOCFCT'],
                "DSMODELODOCORCA"   => $parametros['DSMODELODOCORCA'],
                "IDATIVO"           => $parametros['IDATIVO'],
                "IDDOCRENEGOCIACAO" => $parametros['IDDOCRENEGOCIACAO'],
                "VRTAMANHOLOGO"     => $parametros['VRTAMANHOLOGO'],
                "NRORGULTATU"       => $nrorg,
                "CDOPERULTATU"      => $cdoperador,
            );
            $this->ModeloDocumentoFactory->saveTabModeloDocumento($params);
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarAnexo($params)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($params as $anexo) {
                $dataParam = array(
                    "NRMODELODOCIDIOMA" => $anexo["NRMODELODOCIDIOMA"],
                );
                if (!empty($anexo['DSCAMINHOARQ'])) {
                    $this->fileServerService->deleteFile($anexo['DSCAMINHOARQ']);
                }
                if ($dataParam["NRMODELODOCIDIOMA"] !== null) {
                    $this->ModeloDocumentoFactory->deletarAnexo($dataParam);
                }
                if ($anexo["IDPADRAO"] == "S") {
                    $param = array(
                        "NRSEQMODDOCFCT" => $anexo['NRSEQMODDOCFCT']
                    );
                    $this->ModeloDocumentoFactory->limparAnexoTabModeloDoc($param);
                }
            }
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function deletarModeloDocumento($parametros)
    {
        $this->connection->beginTransaction();
        try {
            foreach ($parametros['NRS'] as $nr) {
                $param = array(
                    "NRSEQMODDOCFCT" => $nr
                );

                $anexos = $this->getTabAnexo($param);
                $this->deletarAnexo($anexos["data"]);
                $this->ModeloDocumentoFactory->deletarModeloDocumento($param);
            }
        
            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }
    
    public function limparAnexoModeloDocumento($parametros)
    {
        $row = $parametros["row"];

        $param = array(
            "NRMODELODOCIDIOMA" => $row["NRMODELODOCIDIOMA"]
        );

        $this->fileServerService->deleteFile($row["DSCAMINHOARQ"]);
        $this->ModeloDocumentoFactory->limparAnexoModeloDocumento($param);

        if ($row["IDPADRAO"] == "S") {
            $param = array(
                "NRSEQMODDOCFCT" => $row["NRSEQMODDOCFCT"]
            );
            $this->ModeloDocumentoFactory->limparAnexoTabModeloDoc($param);
        }
    }
    
    public function downloadAnexoModeloDocumento($idpadrao, $nrmodelodocidioma, $nrseqmoddocfct)
    {
        if ($idpadrao == "S") {
            $param = array(
                "NRSEQMODDOCFCT" => $nrseqmoddocfct
            );
            $dados = $this->ModeloDocumentoFactory->getDocumentoAnt($param);
        } else {
            $param = array(
                "NRMODELODOCIDIOMA" => $nrmodelodocidioma
            );
            $dados = $this->ModeloDocumentoFactory->getDocumento($param);
        }

        $url = $this->fileServerUrl."/files/".$dados[0]['DSCAMINHOARQ'];
        $nomeArquivo = $dados[0]['NMARQUIVO'];
        $tipo = $dados[0]['DSTIPO'];
        $tamanho = $dados[0]['VRTAMANHO']*1024;

        $file = @file_get_contents($url);
        if ($file) {
            Utilities::downloadArquivoFileServer($url, $nomeArquivo, $tipo, $tamanho);
        } else {
            echo "Arquivo não encontrado.";
            exit;
        }
    }
}
