import {
    Http, Metadata,
} from '@zeedhi/core';
import {
    LoadingService, Select, IGridEvent, DialogService,
} from '@zeedhi/common';
import { TekGrid } from '@zeedhi/teknisa-components-common';
import { Utilities } from '@/util/Utilities';

export class Sm00054002ReducaoQuantidadeMedidaController {
    public adicionarReducaoQuantidadeMedidaPerfilAcesso() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso-reducao');
        const newId = 0;
        grid.addNewRow({ NRALTERAQTMEDPERF: newId }, 'start');
    }

    public async inserirReducaoQuantidadeMedidaPerfilAcesso({ event }: IGridEvent) {
        event!.preventDefault();
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso-reducao');
        const perfis = grid.getEditedRows();

        const CurrentRow = grid.datasource.currentRow;
        const UniqueKey = grid.datasource.uniqueKey;
        const currentKey = CurrentRow[UniqueKey];
        const conlumnNRPERFILACESSO = 'NRPERFILACESSO';
        const selectComp = grid.getComponent<Select>(currentKey, conlumnNRPERFILACESSO);

        if (selectComp.validate()) {
            LoadingService.show();
            Http.post('/inserirReducaoQuantidadeMedidaPerfilAcesso', perfis)
                .then(async () => {
                    await grid.cancelEditedRows();
                    await grid.reload();
                    Utilities.showSuccessMessage();
                    grid.datasource.get();
                }).catch((error) => {
                    if (error.response.data.error === 'EXISTE') {
                        Utilities.showDialogMessage('error', 'Operação bloqueada!', 'O Perfil de Acesso informado já está cadastrado.');
                    } else {
                        Utilities.showErrorMessage(error);
                    }
                });
            LoadingService.hide();
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios', 'error');
        }
    }

    public showConfirmDeleteMessagePerfilAcesso({ event }: any) {
        event!.preventDefault();
        DialogService.show({
            name: 'buttons-dialog-operador',
            type: 'warning',
            title: 'Excluir Registro',
            text: 'Deseja realmente excluir todos os registros selecionados?',
            buttons: [
                {
                    name: 'NAO',
                    component: 'ZdButton',
                    label: 'Não',
                    outline: true,
                    events: {
                        click: () => {
                            DialogService.hide();
                        },
                    },
                },
                {
                    name: 'SIM',
                    component: 'ZdButton',
                    label: 'Sim',
                    events: {
                        click: () => {
                            this.deletarReducaoQuantidadeMedidaPerfilAcesso();
                            DialogService.hide();
                        },
                    },
                },
            ],
        });
    }

    public async deletarReducaoQuantidadeMedidaPerfilAcesso() {
        const grid = Metadata.getInstance<TekGrid>('basic-tek-grid-perfil-acesso-reducao');
        LoadingService.show();
        try {
            await Http.post('/deletarReducaoQuantidadeMedidaPerfilAcesso', grid.selectedRows);
            await grid.cancelEditedRows();
            await grid.reload();
            Utilities.showSuccessMessage();
        } catch (e) {
            Utilities.showErrorMessage(e);
        }
        LoadingService.hide();
    }
}
